@@ -10,14 +10,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import configparser
 import errno
 import multiprocessing
 import os
 import shutil
 
-import six
-from six.moves import configparser
-
 from virtualbmc import config as vbmc_config
 from virtualbmc import exception
 from virtualbmc import log
@@ -29,6 +27,7 @@ LOG = log.get_logger()
 # BMC status
 RUNNING = 'running'
 DOWN = 'down'
+ERROR = 'error'
 
 DEFAULT_SECTION = 'VirtualBMC'
 
@@ -78,7 +77,7 @@ class VirtualBMCManager(object):
 
         for option, value in options.items():
             if value is not None:
-                config.set(DEFAULT_SECTION, option, six.text_type(value))
+                config.set(DEFAULT_SECTION, option, str(value))
 
         config_path = os.path.join(
             self.config_dir, options['domain_name'], 'config'
@@ -126,7 +125,7 @@ class VirtualBMCManager(object):
                 vbmc = VirtualBMC(**bmc_config)
 
             except Exception as ex:
-                LOG.error(
+                LOG.exception(
                     'Error running vBMC with configuration '
                     '%(opts)s: %(error)s', {'opts': show_options,
                                             'error': ex}
@@ -137,7 +136,7 @@ class VirtualBMCManager(object):
                 vbmc.listen(timeout=CONF['ipmi']['session_timeout'])
 
             except Exception as ex:
-                LOG.info(
+                LOG.exception(
                     'Shutdown vBMC for domain %(domain)s, cause '
                     '%(error)s', {'domain': show_options['domain_name'],
                                   'error': ex}
@@ -167,7 +166,7 @@ class VirtualBMCManager(object):
 
             if lets_enable:
 
-                if not instance:
+                if not instance or not instance.is_alive():
 
                     instance = multiprocessing.Process(
                         name='vbmcd-managing-domain-%s' % domain_name,
@@ -185,6 +184,13 @@ class VirtualBMCManager(object):
                         '%(domain)s', {'domain': domain_name}
                     )
 
+                if not instance.is_alive():
+                    LOG.debug(
+                        'Found dead vBMC instance for domain %(domain)s '
+                        '(rc %(rc)s)', {'domain': domain_name,
+                                        'rc': instance.exitcode}
+                    )
+
             else:
                 if instance:
                     if instance.is_alive():
@@ -194,13 +200,7 @@ class VirtualBMCManager(object):
                             '%(domain)s', {'domain': domain_name}
                         )
 
-            if instance and not instance.is_alive():
-                del self._running_domains[domain_name]
-                LOG.debug(
-                    'Reaped vBMC instance for domain %(domain)s '
-                    '(rc %(rc)s)', {'domain': domain_name,
-                                    'rc': instance.exitcode}
-                )
+                    self._running_domains.pop(domain_name, None)
 
     def _show(self, domain_name):
         bmc_config = self._parse_config(domain_name)
@@ -216,6 +216,8 @@ class VirtualBMCManager(object):
 
         if instance and instance.is_alive():
             show_options['status'] = RUNNING
+        elif instance and not instance.is_alive():
+            show_options['status'] = ERROR
         else:
             show_options['status'] = DOWN
 
@@ -251,7 +253,7 @@ class VirtualBMCManager(object):
             self._store_config(domain_name=domain_name,
                                username=username,
                                password=password,
-                               port=six.text_type(port),
+                               port=str(port),
                                address=address,
                                libvirt_uri=libvirt_uri,
                                libvirt_sasl_username=libvirt_sasl_username,
@@ -301,6 +303,7 @@ class VirtualBMCManager(object):
                                lets_enable=True)
 
         except Exception as e:
+            LOG.exception('Failed to start domain %s', domain_name)
             return 1, ('Failed to start domain %(domain)s. Error: '
                        '%(error)s' % {'domain': domain_name, 'error': e})
 
@@ -313,6 +316,7 @@ class VirtualBMCManager(object):
             self._vbmc_enabled(domain_name, lets_enable=False)
 
         except Exception as ex:
+            LOG.exception('Failed to stop domain %s', domain_name)
             return 1, str(ex)
 
         self._sync_vbmc_states()
